@@ -2,6 +2,7 @@
 
 It enables papermill to run notebooks against Noteable as though it were executing a notebook locally.
 """
+import asyncio
 import functools
 import json
 import logging
@@ -225,6 +226,10 @@ class NoteableEngine(Engine):
         else:
             ext_logger.info(f"Parameterized notebook available at {parameterized_url}")
 
+        # Temporarily sleep for 1s to wait for file to be available to be subscribed to.
+        # TODO: remove this once Noteable API fix is deployed to prod.
+        await asyncio.sleep(1)
+
         try:
             async with self.setup_kernel(file=self.file, client=self.client, **kwargs):
                 noteable_nb = nbformat.reads(
@@ -447,6 +452,13 @@ class NoteableEngine(Engine):
                     "Timed out while deleting kernel session for file id %s",
                     self.file.id,
                 )
+            except httpx.HTTPStatusError as e:
+                # Ignore any HTTP errors that occur while deleting the kernel session
+                logger.warning(
+                    "Failed to delete kernel session for file id %s. Error: %s",
+                    self.file.id,
+                    e,
+                )
 
     def _get_timeout(self, cell: Optional[NotebookNode]) -> int:
         """Helper to fetch a timeout as a value or a function to be run against a cell"""
