@@ -14,7 +14,7 @@ from dagster import _check as check
 from dagster._core.definitions.events import AssetMaterialization, Failure, Output, RetryRequested
 from dagster._core.definitions.metadata import MetadataValue
 from dagster._core.definitions.utils import validate_tags
-from dagster._core.execution.context.compute import SolidExecutionContext
+from dagster._core.execution.context.compute import OpExecutionContext
 from dagster._core.execution.context.input import build_input_context
 from dagster._core.execution.context.system import StepExecutionContext
 from dagster._core.execution.plan.outputs import StepOutputHandle
@@ -45,7 +45,7 @@ def _dm_compute(
     check.opt_str_param(output_notebook, "output_notebook")
 
     def _t_fn(step_context, inputs):
-        check.inst_param(step_context, "step_context", SolidExecutionContext)
+        check.inst_param(step_context, "step_context", OpExecutionContext)
         check.param_invariant(
             isinstance(step_context.run_config, dict),
             "context",
